/*  lib/le.c  --  Basic little endian byte order functions
 *
 * Copyright (C) 2016 Tomasz Kramkowski <tk@the-tk.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#include <stdint.h>

#include "le.h"

uint16_t le16toh(const void *_data)
{
	const unsigned char *data = _data;

	return (uint16_t)data[0] | (uint16_t)data[1] << 8;
}

uint32_t le32toh(const void *_data)
{
	const unsigned char *data = _data;

	return (uint32_t)data[0] | (uint32_t)data[1] << 8
		| (uint32_t)data[2] << 16 | (uint32_t)data[3] << 24;
}

void htole16(void *_data, uint16_t value)
{
	unsigned char *data = _data;

	data[0] = value >> 0 & 0xff;
	data[1] = value >> 8 & 0xff;
}

void htole32(void *_data, uint32_t value)
{
	unsigned char *data = _data;

	data[0] = value >> 0 & 0xff;
	data[1] = value >> 8 & 0xff;
	data[2] = value >> 16 & 0xff;
	data[3] = value >> 24 & 0xff;
}
